==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1APIServiceStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1APIServiceStatusFluent<A extends V1beta1APIServiceStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V1beta1APIServiceCondition item);
    public A setToConditions(int index,V1beta1APIServiceCondition item);
    public A addToConditions(V1beta1APIServiceCondition... items);
    public A addAllToConditions(Collection<V1beta1APIServiceCondition> items);
    public A removeFromConditions(V1beta1APIServiceCondition... items);
    public A removeAllFromConditions(Collection<V1beta1APIServiceCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1APIServiceCondition> getConditions();
    public List<V1beta1APIServiceCondition> buildConditions();
    public V1beta1APIServiceCondition buildCondition(int index);
    public V1beta1APIServiceCondition buildFirstCondition();
    public V1beta1APIServiceCondition buildLastCondition();
    public V1beta1APIServiceCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1APIServiceConditionBuilder> predicate);
    public A withConditions(List<V1beta1APIServiceCondition> conditions);
    public A withConditions(V1beta1APIServiceCondition... conditions);
    public Boolean hasConditions();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> addNewCondition();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1APIServiceCondition item);
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1APIServiceCondition item);
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editLastCondition();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1APIServiceConditionBuilder> predicate);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1APIServiceConditionFluent<V1beta1APIServiceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1APIServiceStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1APIServiceStatusFluent<A extends V1beta1APIServiceStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V1beta1APIServiceCondition item);
    public A setToConditions(int index,V1beta1APIServiceCondition item);
    public A addToConditions(V1beta1APIServiceCondition... items);
    public A addAllToConditions(Collection<V1beta1APIServiceCondition> items);
    public A removeFromConditions(V1beta1APIServiceCondition... items);
    public A removeAllFromConditions(Collection<V1beta1APIServiceCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1APIServiceCondition> getConditions();
    public List<V1beta1APIServiceCondition> buildConditions();
    public V1beta1APIServiceCondition buildCondition(int index);
    public V1beta1APIServiceCondition buildFirstCondition();
    public V1beta1APIServiceCondition buildLastCondition();
    public V1beta1APIServiceCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1APIServiceConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1APIServiceConditionBuilder> predicate);
    public A withConditions(List<V1beta1APIServiceCondition> conditions);
    public A withConditions(V1beta1APIServiceCondition... conditions);
    public Boolean hasConditions();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> addNewCondition();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1APIServiceCondition item);
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1APIServiceCondition item);
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editLastCondition();
    public V1beta1APIServiceStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1APIServiceConditionBuilder> predicate);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1APIServiceConditionFluent<V1beta1APIServiceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
